@@ -3,6 +3,7 @@ __copyright__ = "Copyright (c) 2021-2021 SZI"
 # Use of this source code is governed by the MIT license.
 __license__ = "MIT"
 
+import json
 import requests
 from bs4 import BeautifulSoup
 
@@ -20,7 +21,7 @@ class ArcaAPI():
     curSession = requests.Session()
 
     def __init__(self, **kwargs):
-        logined = False
+        self.logined = False
         self.kwarg = kwargs
 
     def Csrf_get(self, URL):
@@ -290,3 +291,12 @@ class ArcaAPI():
                    }
         a = self.curSession.post('https://arca.live/api/rate/' + idurl, data=payload)
         self.check_for_error(a)
+
+    def get_cookies(self):
+        return self.curSession.cookies.get_dict()
+
+    def get_notification(self):
+        URL = 'https://arca.live/api/notification'
+        html = self.curSession.get(URL, **self.kwarg)
+        self.check_for_error(html)
+        return json.loads(html.text)
\ No newline at end of file
